import { environment } from "../../../../environments/environment";
import { Injectable } from "@angular/core";
import { CognitoUtil } from "./cognito.service";
import { AuthenticationDetails, CognitoUser } from "amazon-cognito-identity-js";
import * as AWS from "aws-sdk/global";
import * as STS from "aws-sdk/clients/sts";
var UserLoginService = (function () {
    function UserLoginService(cognitoUtil) {
        var _this = this;
        this.cognitoUtil = cognitoUtil;
        this.onLoginSuccess = function (callback, session) {
            console.log("In authenticateUser onSuccess callback");
            AWS.config.credentials = _this.cognitoUtil.buildCognitoCreds(session.getIdToken().getJwtToken());
            // So, when CognitoIdentity authenticates a user, it doesn't actually hand us the IdentityID,
            // used by many of our other handlers. This is handled by some sly underhanded calls to AWS Cognito
            // API's by the SDK itself, automatically when the first AWS SDK request is made that requires our
            // security credentials. The identity is then injected directly into the credentials object.
            // If the first SDK call we make wants to use our IdentityID, we have a
            // chicken and egg problem on our hands. We resolve this problem by "priming" the AWS SDK by calling a
            // very innocuous API call that forces this behavior.
            var clientParams = {};
            if (environment.sts_endpoint) {
                clientParams.endpoint = environment.sts_endpoint;
            }
            var sts = new STS(clientParams);
            sts.getCallerIdentity(function (err, data) {
                console.log("UserLoginService: Successfully set the AWS credentials");
                callback.cognitoCallback(null, session);
            });
        };
        this.onLoginError = function (callback, err) {
            callback.cognitoCallback(err.message, null);
        };
    }
    UserLoginService.prototype.authenticate = function (username, password, callback) {
        var _this = this;
        console.log("UserLoginService: starting the authentication");
        var authenticationData = {
            Username: username,
            Password: password,
        };
        var authenticationDetails = new AuthenticationDetails(authenticationData);
        var userData = {
            Username: username,
            Pool: this.cognitoUtil.getUserPool()
        };
        console.log("UserLoginService: Params set...Authenticating the user");
        var cognitoUser = new CognitoUser(userData);
        console.log("UserLoginService: config is " + AWS.config);
        cognitoUser.authenticateUser(authenticationDetails, {
            newPasswordRequired: function (userAttributes, requiredAttributes) { return callback.cognitoCallback("User needs to set password.", null); },
            onSuccess: function (result) { return _this.onLoginSuccess(callback, result); },
            onFailure: function (err) { return _this.onLoginError(callback, err); },
            mfaRequired: function (challengeName, challengeParameters) {
                callback.handleMFAStep(challengeName, challengeParameters, function (confirmationCode) {
                    cognitoUser.sendMFACode(confirmationCode, {
                        onSuccess: function (result) { return _this.onLoginSuccess(callback, result); },
                        onFailure: function (err) { return _this.onLoginError(callback, err); }
                    });
                });
            }
        });
    };
    UserLoginService.prototype.forgotPassword = function (username, callback) {
        var userData = {
            Username: username,
            Pool: this.cognitoUtil.getUserPool()
        };
        var cognitoUser = new CognitoUser(userData);
        cognitoUser.forgotPassword({
            onSuccess: function () {
            },
            onFailure: function (err) {
                callback.cognitoCallback(err.message, null);
            },
            inputVerificationCode: function () {
                callback.cognitoCallback(null, null);
            }
        });
    };
    UserLoginService.prototype.confirmNewPassword = function (email, verificationCode, password, callback) {
        var userData = {
            Username: email,
            Pool: this.cognitoUtil.getUserPool()
        };
        var cognitoUser = new CognitoUser(userData);
        cognitoUser.confirmPassword(verificationCode, password, {
            onSuccess: function () {
                callback.cognitoCallback(null, null);
            },
            onFailure: function (err) {
                callback.cognitoCallback(err.message, null);
            }
        });
    };
    UserLoginService.prototype.logout = function () {
        console.log("UserLoginService: Logging out");
        this.cognitoUtil.getCurrentUser().signOut();
    };
    UserLoginService.prototype.isAuthenticated = function (callback) {
        if (callback == null)
            throw ("UserLoginService: Callback in isAuthenticated() cannot be null");
        var cognitoUser = this.cognitoUtil.getCurrentUser();
        if (cognitoUser != null) {
            cognitoUser.getSession(function (err, session) {
                if (err) {
                    console.log("UserLoginService: Couldn't get the session: " + err, err.stack);
                    callback.isLoggedIn(err, false);
                }
                else {
                    console.log("UserLoginService: Session is " + session.isValid());
                    callback.isLoggedIn(err, session.isValid());
                }
            });
        }
        else {
            console.log("UserLoginService: can't retrieve the current user");
            callback.isLoggedIn("Can't retrieve the CurrentUser", false);
        }
    };
    UserLoginService.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    UserLoginService.ctorParameters = function () { return [
        { type: CognitoUtil, },
    ]; };
    return UserLoginService;
}());
export { UserLoginService };
//# sourceMappingURL=user-login.service.js.map